@@ -29,7 +29,9 @@ extern "C" {
 
 #define WIN32_LEAN_AND_MEAN
 #define VC_EXTRALEAN
-#define _CRT_SECURE_NO_DEPRECATE  1
+#if !defined(_CRT_SECURE_NO_DEPRECATE)
+#  define _CRT_SECURE_NO_DEPRECATE  1
+#endif
 #include <windows.h>
 #include <wchar.h>
 #include <winuser.h>
@@ -99,7 +101,9 @@ extern "C" {
 #if !defined(closedir)
 #  define closedir(directory)  NTCloseDirectory(directory)
 #endif
-#define MAGICKCORE_HAVE_ERF
+#if !defined(MAGICKCORE_HAVE_ERF)
+#  define MAGICKCORE_HAVE_ERF
+#endif
 #if defined(_VISUALC_) && (_MSC_VER < 1700)
 #  define erf(x)  NTErf(x)
 #endif
@@ -112,32 +116,9 @@ extern "C" {
 #if !defined(freelocale)
 #  define freelocale  _free_locale
 #endif
-#if !defined(fseek) && !defined(__MINGW32__)
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && \
-  !(defined(_MSC_VER) && (_MSC_VER < 1400)) && \
-  !(defined(__MSVCRT_VERSION__) && (__MSVCRT_VERSION__ < 0x800))
-#  define fseek  _fseeki64
-#endif
-#endif
-#if !defined(fstat) && !defined(__BORLANDC__)
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && \
-  !(defined(_MSC_VER) && (_MSC_VER < 1400)) && \
-  !(defined(__MSVCRT_VERSION__) && (__MSVCRT_VERSION__ < 0x800))
-#  define fstat  _fstati64
-#else
-#  define fstat  _fstat
-#endif
-#endif
 #if !defined(fsync)
 #  define fsync  _commit
 #endif
-#if !defined(ftell) && !defined(__MINGW32__)
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && \
-  !(defined(_MSC_VER) && (_MSC_VER < 1400)) && \
-  !(defined(__MSVCRT_VERSION__) && (__MSVCRT_VERSION__ < 0x800))
-#  define ftell  _ftelli64
-#endif
-#endif
 #if !defined(ftruncate)
 #  define ftruncate(file,length)  NTTruncateFile(file,length)
 #endif
@@ -156,17 +137,6 @@ extern "C" {
 #if !defined(locale_t)
 #define locale_t _locale_t
 #endif
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && \
-  !(defined(_MSC_VER) && (_MSC_VER < 1400)) && \
-  !(defined(__MSVCRT_VERSION__) && (__MSVCRT_VERSION__ < 0x800))
-#if !defined(lseek)
-#  define lseek  _lseeki64
-#endif
-#else
-#if !defined(lseek)
-#  define lseek  _lseek
-#endif
-#endif
 #if !defined(MAGICKCORE_LTDL_DELEGATE)
 #if !defined(lt_dlclose)
 #  define lt_dlclose(handle)  NTCloseLibrary(handle)
@@ -231,15 +201,6 @@ extern "C" {
 #if !defined(strtod_l)
 #define strtod_l  _strtod_l
 #endif
-#if !defined(stat) && !defined(__BORLANDC__)
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && \
-  !(defined(_MSC_VER) && (_MSC_VER < 1400)) && \
-  !(defined(__MSVCRT_VERSION__) && (__MSVCRT_VERSION__ < 0x800))
-#  define stat  _stati64
-#else
-#  define stat  _stat
-#endif
-#endif
 #if !defined(strcasecmp)
 #  define strcasecmp  _stricmp
 #endif
@@ -250,13 +211,6 @@ extern "C" {
 #  define sysconf(name)  NTSystemConfiguration(name)
 #  define MAGICKCORE_HAVE_SYSCONF 1
 #endif
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && \
-  !(defined(_MSC_VER) && (_MSC_VER < 1400)) && \
-  !(defined(__MSVCRT_VERSION__) && (__MSVCRT_VERSION__ < 0x800))
-#  define tell  _telli64
-#else
-#  define tell  _tell
-#endif
 #if !defined(tempnam)
 #  define tempnam  _tempnam_s
 #endif
@@ -272,6 +226,7 @@ extern "C" {
 #if !defined(unlink)
 #  define unlink  _unlink
 #endif
+#define MAGICKCORE_HAVE_UTIME 1
 #if !defined(utime)
 #  define utime(filename,time)  _utime(filename,(struct _utimbuf*) time)
 #endif
@@ -289,14 +244,55 @@ extern "C" {
 #if !defined(write)
 #  define write(fd,buffer,count)  _write(fd,buffer,(unsigned int) count)
 #endif
-#if !defined(wstat) && !defined(__BORLANDC__)
 #if defined(MAGICKCORE_WINDOWS_SUPPORT) && \
+  !(defined(__BORLANDC__)) && \
   !(defined(_MSC_VER) && (_MSC_VER < 1400)) && \
   !(defined(__MSVCRT_VERSION__) && (__MSVCRT_VERSION__ < 0x800))
-#  define wstat  _wstati64
+#  if !defined(fseek)
+#    define fseek  _fseeki64
+#  endif
+#  if !defined(ftell)
+#    define ftell  _ftelli64
+#  endif
+#  if !defined(lseek)
+#    define lseek  _lseeki64
+#  endif
+#  if !defined(fstat)
+#    define fstat  _fstati64
+#  endif
+#  if !defined(stat)
+#    define stat  _stati64
+#  endif
+#  if !defined(tell)
+#    define tell  _telli64
+#  endif
+#  if !defined(wstat)
+#    define wstat  _wstati64
+#  endif
 #else
-#  define wstat  _wstat
-#endif
+#  if !defined(__MINGW32__)
+#    if !defined(fseek)
+#      define fseek  _fseek
+#    endif
+#    if !defined(ftell)
+#      define ftell  _ftell
+#    endif
+#  endif
+#  if !defined(lseek)
+#    define lseek  _lseek
+#  endif
+#  if !defined(fstat)
+#    define fstat  _fstat
+#  endif
+#  if !defined(stat)
+#    define stat  _stat
+#  endif
+#  if !defined(tell)
+#    define tell  _tell
+#  endif
+#  if !defined(wstat)
+#    define wstat  _wstat
+#  endif
 #endif
 
 #if defined(__BORLANDC__)
